@@ -114,7 +114,7 @@ async def get_asm(id: int = choose().asmhentai):
                 try:
                     desired = inputimeout(
                         prompt="Do you want to render it all to .pdf? (y/n) ",
-                        timeout=10,
+                        timeout=7,
                     )
                     to_pdf = desired
 
@@ -145,4 +145,4 @@ async def get_asm(id: int = choose().asmhentai):
                 except TimeoutOccurred:
                     print("Timeout occurred")
                     os.remove(neat_dir + "/" + t)
-                    exit()
+                    ## exit()
