@@ -91,7 +91,7 @@ async def get_nh(id: int = choose().nhentai):
                 try:
                     desired = inputimeout(
                         prompt="Do you want to render it all to .pdf? (y/n) ",
-                        timeout=10,
+                        timeout=7,
                     )
                     to_pdf = desired
 
@@ -122,4 +122,4 @@ async def get_nh(id: int = choose().nhentai):
                 except TimeoutOccurred:
                     print("Timeout occurred")
                     os.remove(neat_dir + "/" + t)
-                    exit()
+                    ## exit()
