@@ -92,7 +92,7 @@ async def get_pur(id: int = choose().pururin):
                 try:
                     desired = inputimeout(
                         prompt="Do you want to render it all to .pdf? (y/n) ",
-                        timeout=10,
+                        timeout=7,
                     )
                     to_pdf = desired
 
@@ -123,4 +123,4 @@ async def get_pur(id: int = choose().pururin):
                 except TimeoutOccurred:
                     print("Timeout occurred")
                     os.remove(neat_dir + "/" + t)
-                    exit()
+                    ## exit()
